function [data] = bootstrapdataset(data)

% Function that creates the stratification variables to be appended to each
% dataset that must be resampled.


% Step 1: BlueChip GDP data.
% Here create strata to deal with missing observations for 4 to 7 quarters
% ahead expectations.

data.ddGDP.stratum = zeros(length(data.ddGDP),1);
data.ddGDP.stratum(and(and(and(isnan(data.ddGDP.DRealGDP_F4q),...
                               isnan(data.ddGDP.DRealGDP_F5q)), ...
                           isnan(data.ddGDP.DRealGDP_F6q)), ...
                       isnan(data.ddGDP.DRealGDP_F7q))) = 1;
data.ddGDP.stratum(and(and(and(~isnan(data.ddGDP.DRealGDP_F4q),...
                               isnan(data.ddGDP.DRealGDP_F5q)), ...
                           isnan(data.ddGDP.DRealGDP_F6q)), ...
                       isnan(data.ddGDP.DRealGDP_F7q))) = 2;
data.ddGDP.stratum(and(and(and(~isnan(data.ddGDP.DRealGDP_F4q),...
                               ~isnan(data.ddGDP.DRealGDP_F5q)), ...
                           isnan(data.ddGDP.DRealGDP_F6q)), ...
                       isnan(data.ddGDP.DRealGDP_F7q))) = 3;
data.ddGDP.stratum(and(and(and(~isnan(data.ddGDP.DRealGDP_F4q),...
                               ~isnan(data.ddGDP.DRealGDP_F5q)), ...
                           ~isnan(data.ddGDP.DRealGDP_F6q)), ...
                       isnan(data.ddGDP.DRealGDP_F7q))) = 4;

                   
% Stop 2: Daily/Tick data on interest rates, inflation, stock price. 
% Here deal with the problem that some moments are only estimated using
% information from 2004 onwards.
% 
data.dd1.stratum = zeros(length(data.dd1),1);
data.dd1.stratum(and(data.dd1.FOMCused == 1,...
                     data.dd1.year < 2004), 1) = 1;
data.dd1.stratum(and(data.dd1.FOMCused == 0,...
                     data.dd1.year < 2004), 1) = 2;
data.dd1.stratum(and(data.dd1.FOMCused == 1,...
                     data.dd1.year >= 2004), 1) = 3;
data.dd1.stratum(and(data.dd1.FOMCused == 0,...
                     data.dd1.year >= 2004), 1) = 4;  
                 
end